"-------------------------------------------------------------------------------
" Vim syntax highlighting
" Language : C
" Author : Rob Bassett
" Last Change : 2015/01/09
" Remark : Avago APD highlighting for cross-check files
" Version : 0.1.0
"-------------------------------------------------------------------------------
"" check to see if a syntax has already been defined for this type of file
"-------------------------------------------------------------------------------

if exists("b:current_syntax")
    finish
endif

"-------------------------------------------------------------------------------
syntax clear
"-------------------------------------------------------------------------------

"-------------------------------------------------------------------------------
" First define a chunk of syntax using syntax keyword
" The syntax keyword command appends to the previous list

"-------------------------------------------------------------------------------
" Shell commands to highlight
syntax keyword inCommand zgrep grep 
syntax keyword inCommand zcat cat 
syntax keyword inCommand zdiff diff 
syntax keyword inCommand display 
syntax keyword inCommand perl awk sed 
syntax keyword inCommand sort 
syntax keyword inCommand find 
syntax keyword inCommand cd 
syntax keyword inCommand export 
syntax keyword inCommand make_flow make_target check_dm 
syntax keyword inCommand ls 
syntax keyword inCommand less
highlight link inCommand Operator

"-------------------------------------------------------------------------------
" highlight the header of each cross-check section 
syntax keyword inKeyword BLOCKNAME 
syntax keyword inKeyword BLOCK_BUILDER 
syntax keyword inKeyword CROSS_CHECKER 
syntax keyword inKeyword DATE_FINISHED 
syntax keyword inKeyword CROSS_CHECK_PERFORMED 
syntax keyword inKeyword CROSS_CHECK_STATUS 
syntax keyword inKeyword CROSS_CHECK_CONCERNS 
syntax keyword inKeyword CROSS_CHECK_ID 
syntax keyword inKeyword STATUS 
syntax keyword inKeyword LIMIT
syntax keyword inKeyword TYPE
syntax keyword inKeyword CATEGORY
"syntax keyword inKeyword CATEGORY nextgroup=inDesc skipwhite
syntax keyword inKeyword DESCRIPTION
syntax keyword inKeyword COMMENT_SECTION
syntax keyword inKeyword BLOCK_DESIGNER_WAIVER
syntax keyword inKeyword CROSS_CHECKER_COMMENTS
syntax keyword inKeyword CROSS_CHECKER_COMMENTS
syntax keyword inKeyword CHECKS
syntax keyword inKeyword REQUIRED
syntax keyword inKeyword REQUIREMENT
" Link the chunk to a highlighting group
highlight link inKeyword Keyword

"-------------------------------------------------------------------------------
" UNUSED SO FAR
"syntax keyword inType PASS-WAIVER pass-waiver
"syntax keyword inType PASS pass
"syntax keyword inType NOT_REQUIRED not_required
"syntax keyword inType OPTIONAL optional
""highlight link inType Type
"highlight link inType Statement

"-------------------------------------------------------------------------------
"syntax keyword inDebug FAIL fail
"highlight link inDebug Debug

"-------------------------------------------------------------------------------
" highlight the fields contained between parentheses
syntax region inQuote matchgroup=Clear start='"' end='"'
highlight link inQuote String

"-------------------------------------------------------------------------------
" highlight the fields contained between parentheses
syntax region inParen matchgroup=Special start='(' end=')'
highlight link inParen PreProc

"-------------------------------------------------------------------------------
" highlight the fields contained between curly braces
syntax region inDesc matchgroup=PreProc start='{' end='}' contains=inDescPass,inDescFail,inDescNA
highlight link inDesc Constant

" highlight PASS*/pass* entries in fields contained between curly braces
syntax keyword inDescPass contained PASS Pass pass 
syntax keyword inDescPass contained PASS-WAIVER pass-waiver
syntax keyword inDescPass contained Pass-Waiver Pass-waiver
syntax keyword inDescPass contained Pass-Waive Pass-waive
highlight link inDescPass Comment

" highlight FAIL*/fail* entries in fields contained between curly braces
syntax keyword inDescFail contained FAIL fail Fail
highlight link inDescFail Error

" highlight NA / N/A entries in fields contained between curly braces
syntax keyword inDescNA contained NA "N/A"
highlight link inDescNA WarningMsg

"-------------------------------------------------------------------------------
" Not working???
" highlight the fields indicating variables
syntax keyword inVar '\$' nextgroup=PreProc
highlight link inVar PreProc 

"-------------------------------------------------------------------------------
" highlight the fields indicating Failures
syntax keyword inFixMe ERROR Error
syntax keyword inFixMe FAIL fail
highlight link inFixMe Error

"-------------------------------------------------------------------------------
" highlight the fields indicating things left to check or do
syntax keyword inToDo    CHECK
syntax keyword inToDo    TODO
highlight link inToDo    Todo

"-------------------------------------------------------------------------------
" highlight the comment fields
syntax keyword inComment NOTE
syntax keyword inComment COMPLETED
syntax keyword inComment OR
syntax keyword inComment SET
highlight link inComment Comment

"-------------------------------------------------------------------------------
" highlight the orignal comment fields differently than user comments
syntax match   inOrigComment "%%.*$" contains=inOrigCommentKeyword,inOrigCommentKeyword2
syntax keyword inOrigCommentKeyword2 contained COMMENT
syntax keyword inOrigCommentKeyword2 contained SECTION
syntax keyword inOrigCommentKeyword2 contained ONLY
syntax keyword inOrigCommentKeyword2 contained NECESSARY
syntax keyword inOrigCommentKeyword2 contained NOTE Note
syntax keyword inOrigCommentKeyword2 contained OR
syntax keyword inOrigCommentKeyword2 contained AND
syntax keyword inOrigCommentKeyword2 contained ALL
syntax keyword inOrigCommentKeyword2 contained IF if If
syntax keyword inOrigCommentKeyword contained Check check
syntax keyword inOrigCommentKeyword contained Verify verify
syntax keyword inOrigCommentKeyword contained BLOCK
syntax keyword inOrigCommentKeyword contained DESIGNER
syntax keyword inOrigCommentKeyword contained INPUT
"highlight link inOrigComment SignColumn
highlight link inOrigComment Identifier
highlight link inOrigCommentKeyword2 Special
highlight link inOrigCommentKeyword Comment

"-------------------------------------------------------------------------------
" highlight keywords inside the comment fields
syntax match   inComment "# .*$" contains=inCommentKeyword
highlight link inCommentKeyword Keyword

"-------------------------------------------------------------------------------
" User customization section
"-------------------------------------------------------------------------------
" highlight my name in a comment
syntax keyword inCommentKeyword contained loki

" highlight other block builder names in a comment
syntax keyword inCommentKeyword contained Ravi

" highlight other block builder names that are in file listings (uncommented)
syntax keyword inKeyword gandhip_ei
syntax keyword inKeyword sagarvam_ei

" highlight other block builder names at start of comment
syntax match   inComment "#Manish.*$"
syntax match   inComment "#\*Manish.*$"

"-------------------------------------------------------------------------------
"" Set the syntax definition for "*.in" files
"-------------------------------------------------------------------------------
let b:current_syntax = "in"
"-------------------------------------------------------------------------------
